<?php
/**
 * 短信宝短信接口发送实现
*/

namespace Niaoyun\Common\Sms;

class SmsBaosms extends BaseSms implements ISms
{
    private $errorArr = [
        -1    => '参数不全',
		-2    => '服务器空间不支持',
		30    => '错误密码',
		40    => '账号不存在',
		41    => '余额不足',
		43    => 'IP地址限制',
		50    => '内容含有敏感词',
		51    => '手机号码不正确',
    ];
	private $config;            // 配置

    /**
     * 构造函数
     * 设置短信接口配置信息
     */
    public function __construct()
    {
        $this->config = [
            'url'       => 'http://api.smsbao.com/',
            'u'  => '短信宝账号',
            'p'   => '短信宝密码',
            'signature' => '【短信宝签名】', // 短信内容签名
        ];
    }
    public function send($mobile, $content, $id = null, $type = 2, $param = [], $handleResult = true)
    {
		$smsapi = $this->config['url'];
		$u = $this->config['u'];
		$p = md5($this->config['p']);
		$c = $content . $this->config['signature'];
		$m = $mobile;
		$sendurl = $smsapi."sms?u=".$u."&p=".$p."&m=".$m."&c=".urlencode($c);
		$result =file_get_contents($sendurl) ;
        return $this->processSendResult($result);
    }

    /**
     * 处理短信接口返回信息
     * @auth King
     *
     * @param $result
     *
     * @return bool
     */
    public function processSendResult($result)
    {
       if (is_bool($result) && !$result) {
            $this->error = '接口不通';
            return $result;
        }
		if (array_key_exists($result, $this->errorArr)) {
            $this->error = $this->errorArr[$result];
            return false;
        }
		if (is_numeric($result) && $result < 0) {
            $this->error = $result . ' 未知错误';
            return false;
        }
		return true;
    }
}